==> myri-pcie-tool-1.6-linux.tar.gz: myri-pcie-tool-1.6-linux/myrige-test.sh <==
#!/bin/bash

set -e

# find the path in which the script is located
script=`type -p $0`
case $script in 
  /*) : ;;
  *) script=$PWD/$script;;
esac
dir=`dirname $script`

args="`getopt lb:t:h "$@"`"
set -- $args

boardnum=0

error()
{
    trap 0
    echo "[FAILURE] $@" >&2
    test -z "$loopback_connector" && $dir/ze_loopback -0
    exit 1
}

usage()
{
   trap 0
    echo "usage: myrige-test.sh [ -l ] [ -t <secs> ] [ -b<rank> ]
    -l : an external loopback connector is used
    -t <secs> : duration of the test (default 4s)
    -b <n> : for machine with multiple NIC, test <n>th NIC"
  exit 1
    
}

trap error 0

time=4
loopback_type="(Internal loopback)"

while test $# -ge 1 ; do
 case "$1" in
  -l) loopback_connector=1;shift 1
  loopback_type="(External loopback setup)"
  ;;
  -t) time=$2;shift 2;;
  -b) boardnum=$2;shift 2;;
  -h) usage;;
  --) shift 1;;
  *) echo "Unkown param:$1" >&2;exit 1
 esac
done



load()
{
    rmmod myri10ge 2> /dev/null || :
#     if (cd / && modinfo  myri10ge) | grep -q myri10ge_iprev &&
# 	(cd / && modinfo myri10ge) | grep -q myri10ge_recovery ; then 
#       params="myri10ge_iprev=1 myri10ge_recovery=0"
#       ip_loopback=1
#     fi
    modprobe myri10ge $params
    for f in `seq 0 6` ; do 
	intf=eth${f}
	if ethtool -i $intf 2> /dev/null | grep -q myri10ge; then
	    intfs="$intfs $intf"
	fi
    done
    set -- $intfs
    shift "$boardnum"
    intf="$1"
    if test -z "$intf" ; then
	error "Cannot find interface for myri10ge NIC instance # $boardnum"
    fi
}

setarp()
{
   mac=`ifconfig $intf | sed -ne 's/.*HWaddr \(..:..:..:..:..:..*\).*/\1/p'`
   test -n "$mac" || error "Cannot find Mac for $intf"
   ifconfig $intf 10.108.111.112 netmask 255.255.255.255
#   route add -host 10.108.111.113 dev $intf
#   arp -i $intf -s 10.108.111.113 $mac
}




load

setarp

echo
echo "Testing MYRI-10G NIC: $mac $loopback_type"
echo "==========================================================="
echo
#if test -n "$ip_loopback" ; then 
#  $dir/myri_loop_test -d 10.108.111.113 -t $time
#fi

if test -z "$loopback_connector" ; then
  $dir/ze_loopback -1
else
  $dir/ze_loopback -0
fi
$dir/myri_loop_test -m $mac -t $time
test -z "$loopback_connector" && $dir/ze_loopback -0

trap 0

sleep 2
rmmod myri10ge

==> myri-pcie-tool-1.11-linux.tar.gz: myri-pcie-tool-1.11-linux/myrige-test.sh <==
#!/bin/bash

set -e

# find the path in which the script is located
script=`type -p $0`
case $script in 
  /*) : ;;
  *) script=$PWD/$script;;
esac
dir=`dirname $script`

args="`getopt lb:t:h "$@"`"
set -- $args

boardnum=0

error()
{
    trap 0
    echo "[FAILURE] $@" >&2
    test -z "$loopback_connector" && $dir/ze_loopback -0 -b$boardnum
    exit 1
}

usage()
{
   trap 0
    echo "usage: myrige-test.sh [ -l ] [ -t <secs> ] [ -b<rank> ]
    -l : an external loopback connector is used
    -t <secs> : duration of the test (default 4s)
    -b <n> : for machine with multiple NIC, test <n>th NIC"
  exit 1
    
}


time=4
loopback_type="(Internal loopback)"

while test $# -ge 1 ; do
 case "$1" in
  -l) loopback_connector=1;shift 1
  loopback_type="(External loopback setup)"
  ;;
  -t) time=$2;shift 2;;
  -b) boardnum=$2;shift 2;;
  -h) usage;;
  --) shift 1;;
  *) echo "Unkown param:$1" >&2;exit 1
 esac
done


trap error 0

load()
{
    rmmod myri10ge 2> /dev/null || :
#     if (cd / && modinfo  myri10ge) | grep -q myri10ge_iprev &&
# 	(cd / && modinfo myri10ge) | grep -q myri10ge_recovery ; then 
#       params="myri10ge_iprev=1 myri10ge_recovery=0"
#       ip_loopback=1
#     fi
    modprobe myri10ge $params
    for intf in  `sed -ne 's/^\([^:]*\):.*/\1/p' /proc/net/dev` ; do 
	if ethtool -i $intf 2> /dev/null | grep -q myri10ge; then
	    intfs="$intfs $intf"
	fi
    done
    set -- $intfs
    shift "$boardnum"
    intf="$1"
    if test -z "$intf" ; then
	error "Cannot find interface for myri10ge NIC instance # $boardnum"
    fi
}

setarp()
{
   mac=`ifconfig $intf | sed -ne 's/.*HWaddr \(..:..:..:..:..:..*\).*/\1/p'`
   test -n "$mac" || error "Cannot find Mac for $intf"
   ifconfig $intf 10.108.111.112 netmask 255.255.255.255
#   route add -host 10.108.111.113 dev $intf
#   arp -i $intf -s 10.108.111.113 $mac
}




load

setarp

echo
echo "Testing MYRI-10G NIC: $mac $loopback_type"
echo "==========================================================="
echo
#if test -n "$ip_loopback" ; then 
#  $dir/myri_loop_test -d 10.108.111.113 -t $time
#fi

if test -z "$loopback_connector" ; then
  $dir/ze_loopback -1 -b$boardnum
else
  $dir/ze_loopback -0 -b$boardnum
fi
sleep 1
$dir/myri_loop_test -m $mac -t $time
test -z "$loopback_connector" && $dir/ze_loopback -0  -b$boardnum

trap 0
